from setuptools import setup
  
setup(
    name="liker",
    version="0.0.3",
    author="kwhkim",
    description="functions that mimic R",
    long_description ="file: README.md",
    py_modules=["liker"]
)
# https://towardsdatascience.com/setuptools-python-571e7d5500f2

